# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.job_spec_input import JobSpecInput

class TestJobSpecInput(unittest.TestCase):
    """JobSpecInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobSpecInput:
        """Test JobSpecInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobSpecInput`
        """
        model = JobSpecInput()
        if include_optional:
            return JobSpecInput(
                executable = '/usr/bin/python',
                container = { },
                arguments = [-n, 100],
                directory = '/home/user/work',
                name = 'my-job',
                inherit_environment = True,
                environment = {OMP_NUM_THREADS=4},
                stdin_path = '/home/user/input.txt',
                stdout_path = '/home/user/output.txt',
                stderr_path = '/home/user/error.txt',
                resources = {
                    'key' : null
                    },
                attributes = { },
                pre_launch = 'module load cuda',
                post_launch = 'echo done',
                launcher = 'srun'
            )
        else:
            return JobSpecInput(
        )
        """

    def testJobSpecInput(self):
        """Test JobSpecInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from esnet_iri.models.container import Container
from esnet_iri.models.job_attributes import JobAttributes
from esnet_iri.models.resource_spec import ResourceSpec
from typing import Optional, Set
from typing_extensions import Self

class JobSpecInput(BaseModel):
    """
    Specification for a job.
    """ # noqa: E501
    executable: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Path to the executable to run. If container is specified, this will be used as the entrypoint to the container.")
    container: Optional[Container] = Field(default=None, description="Container specification for containerized execution")
    arguments: Optional[List[StrictStr]] = Field(default=None, description="Command-line arguments to pass to the executable or container")
    directory: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Working directory for the job")
    name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Name of the job")
    inherit_environment: Optional[StrictBool] = Field(default=True, description="Whether to inherit the environment variables from the submission environment")
    environment: Optional[Dict[str, StrictStr]] = Field(default=None, description="Environment variables to set for the job. If container is specified, these will be set inside the container.")
    stdin_path: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Path to file to use as standard input")
    stdout_path: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Path to file to write standard output")
    stderr_path: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Path to file to write standard error")
    resources: Optional[ResourceSpec] = Field(default=None, description="Resource requirements for the job")
    attributes: Optional[JobAttributes] = Field(default=None, description="Additional job attributes such as duration, queue, and account")
    pre_launch: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Script or commands to run before launching the job")
    post_launch: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Script or commands to run after the job completes")
    launcher: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Job launcher to use (e.g., 'mpirun', 'srun')")
    __properties: ClassVar[List[str]] = ["executable", "container", "arguments", "directory", "name", "inherit_environment", "environment", "stdin_path", "stdout_path", "stderr_path", "resources", "attributes", "pre_launch", "post_launch", "launcher"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of JobSpecInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of container
        if self.container:
            _dict['container'] = self.container.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of attributes
        if self.attributes:
            _dict['attributes'] = self.attributes.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of JobSpecInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "executable": obj.get("executable"),
            "container": Container.from_dict(obj["container"]) if obj.get("container") is not None else None,
            "arguments": obj.get("arguments"),
            "directory": obj.get("directory"),
            "name": obj.get("name"),
            "inherit_environment": obj.get("inherit_environment") if obj.get("inherit_environment") is not None else True,
            "environment": obj.get("environment"),
            "stdin_path": obj.get("stdin_path"),
            "stdout_path": obj.get("stdout_path"),
            "stderr_path": obj.get("stderr_path"),
            "resources": ResourceSpec.from_dict(obj["resources"]) if obj.get("resources") is not None else None,
            "attributes": JobAttributes.from_dict(obj["attributes"]) if obj.get("attributes") is not None else None,
            "pre_launch": obj.get("pre_launch"),
            "post_launch": obj.get("post_launch"),
            "launcher": obj.get("launcher")
        })
        return _obj





# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.incident import Incident

class TestIncident(unittest.TestCase):
    """Incident unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Incident:
        """Test Incident
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Incident`
        """
        model = Incident()
        if include_optional:
            return Incident(
                id = 'urn:iri:object:1234',
                name = '',
                description = '',
                last_modified = '2026-02-21T12:00:00Z',
                status = 'up',
                start = '2026-02-21T12:00:00Z',
                end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                type = 'planned',
                resolution = 'unresolved',
                self_uri = '',
                event_uris = [
                    ''
                    ],
                resource_uris = [
                    ''
                    ]
            )
        else:
            return Incident(
                id = 'urn:iri:object:1234',
                last_modified = '2026-02-21T12:00:00Z',
                status = 'up',
                start = '2026-02-21T12:00:00Z',
                type = 'planned',
                resolution = 'unresolved',
                self_uri = '',
                event_uris = [
                    ''
                    ],
                resource_uris = [
                    ''
                    ],
        )
        """

    def testIncident(self):
        """Test Incident"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated
from esnet_iri.models.job import Job
from esnet_iri.models.job_spec_input import JobSpecInput

from esnet_iri.api_client import ApiClient, RequestSerialized
from esnet_iri.api_response import ApiResponse
from esnet_iri.rest import RESTResponseType


class ComputeApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def cancel_job(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Cancel Job

        Cancel a job

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def cancel_job_with_http_info(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Cancel Job

        Cancel a job

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def cancel_job_without_preload_content(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Cancel Job

        Cancel a job

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _cancel_job_serialize(
        self,
        resource_id,
        job_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resource_id'] = resource_id
        if job_id is not None:
            _path_params['job_id'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v1/compute/cancel/{resource_id}/{job_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_job(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        historical: Annotated[Optional[StrictBool], Field(description="Whether to include historical jobs. Defaults to false")] = None,
        include_spec: Annotated[Optional[StrictBool], Field(description="Whether to include the job specification. Defaults to false")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Job:
        """Get Job Status

        Get a job's status

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param historical: Whether to include historical jobs. Defaults to false
        :type historical: bool
        :param include_spec: Whether to include the job specification. Defaults to false
        :type include_spec: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            historical=historical,
            include_spec=include_spec,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_job_with_http_info(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        historical: Annotated[Optional[StrictBool], Field(description="Whether to include historical jobs. Defaults to false")] = None,
        include_spec: Annotated[Optional[StrictBool], Field(description="Whether to include the job specification. Defaults to false")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Job]:
        """Get Job Status

        Get a job's status

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param historical: Whether to include historical jobs. Defaults to false
        :type historical: bool
        :param include_spec: Whether to include the job specification. Defaults to false
        :type include_spec: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            historical=historical,
            include_spec=include_spec,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_job_without_preload_content(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        historical: Annotated[Optional[StrictBool], Field(description="Whether to include historical jobs. Defaults to false")] = None,
        include_spec: Annotated[Optional[StrictBool], Field(description="Whether to include the job specification. Defaults to false")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Job Status

        Get a job's status

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param historical: Whether to include historical jobs. Defaults to false
        :type historical: bool
        :param include_spec: Whether to include the job specification. Defaults to false
        :type include_spec: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            historical=historical,
            include_spec=include_spec,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_job_serialize(
        self,
        resource_id,
        job_id,
        historical,
        include_spec,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resource_id'] = resource_id
        if job_id is not None:
            _path_params['job_id'] = job_id
        # process the query parameters
        if historical is not None:
            
            _query_params.append(('historical', historical))
            
        if include_spec is not None:
            
            _query_params.append(('include_spec', include_spec))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/compute/status/{resource_id}/{job_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_jobs(
        self,
        resource_id: StrictStr,
        offset: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        limit: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        historical: Annotated[Optional[StrictBool], Field(description="Whether to include historical jobs. Defaults to false")] = None,
        include_spec: Annotated[Optional[StrictBool], Field(description="Whether to include the job specification. Defaults to false")] = None,
        request_body: Optional[Dict[str, Any]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Job]:
        """Get Job Statuses

        Get multiple jobs' statuses

        :param resource_id: (required)
        :type resource_id: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param historical: Whether to include historical jobs. Defaults to false
        :type historical: bool
        :param include_spec: Whether to include the job specification. Defaults to false
        :type include_spec: bool
        :param request_body:
        :type request_body: Dict[str, object]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_jobs_serialize(
            resource_id=resource_id,
            offset=offset,
            limit=limit,
            historical=historical,
            include_spec=include_spec,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Job]",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_jobs_with_http_info(
        self,
        resource_id: StrictStr,
        offset: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        limit: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        historical: Annotated[Optional[StrictBool], Field(description="Whether to include historical jobs. Defaults to false")] = None,
        include_spec: Annotated[Optional[StrictBool], Field(description="Whether to include the job specification. Defaults to false")] = None,
        request_body: Optional[Dict[str, Any]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Job]]:
        """Get Job Statuses

        Get multiple jobs' statuses

        :param resource_id: (required)
        :type resource_id: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param historical: Whether to include historical jobs. Defaults to false
        :type historical: bool
        :param include_spec: Whether to include the job specification. Defaults to false
        :type include_spec: bool
        :param request_body:
        :type request_body: Dict[str, object]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_jobs_serialize(
            resource_id=resource_id,
            offset=offset,
            limit=limit,
            historical=historical,
            include_spec=include_spec,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Job]",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_jobs_without_preload_content(
        self,
        resource_id: StrictStr,
        offset: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        limit: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        historical: Annotated[Optional[StrictBool], Field(description="Whether to include historical jobs. Defaults to false")] = None,
        include_spec: Annotated[Optional[StrictBool], Field(description="Whether to include the job specification. Defaults to false")] = None,
        request_body: Optional[Dict[str, Any]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Job Statuses

        Get multiple jobs' statuses

        :param resource_id: (required)
        :type resource_id: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param historical: Whether to include historical jobs. Defaults to false
        :type historical: bool
        :param include_spec: Whether to include the job specification. Defaults to false
        :type include_spec: bool
        :param request_body:
        :type request_body: Dict[str, object]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_jobs_serialize(
            resource_id=resource_id,
            offset=offset,
            limit=limit,
            historical=historical,
            include_spec=include_spec,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Job]",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_jobs_serialize(
        self,
        resource_id,
        offset,
        limit,
        historical,
        include_spec,
        request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resource_id'] = resource_id
        # process the query parameters
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if historical is not None:
            
            _query_params.append(('historical', historical))
            
        if include_spec is not None:
            
            _query_params.append(('include_spec', include_spec))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request_body is not None:
            _body_params = request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/compute/status/{resource_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def launch_job(
        self,
        resource_id: StrictStr,
        job_spec_input: JobSpecInput,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Job:
        """Submit Job

        Submit a job on a compute resource  - **resource**: the name of the compute resource to use - **job_request**: a PSIJ job spec as defined <a href=\"https://exaworks.org/psij-python/docs/v/0.9.11/.generated/tree.html#jobspec\">here</a>  This command will attempt to submit a job and return its id.

        :param resource_id: (required)
        :type resource_id: str
        :param job_spec_input: (required)
        :type job_spec_input: JobSpecInput
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._launch_job_serialize(
            resource_id=resource_id,
            job_spec_input=job_spec_input,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def launch_job_with_http_info(
        self,
        resource_id: StrictStr,
        job_spec_input: JobSpecInput,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Job]:
        """Submit Job

        Submit a job on a compute resource  - **resource**: the name of the compute resource to use - **job_request**: a PSIJ job spec as defined <a href=\"https://exaworks.org/psij-python/docs/v/0.9.11/.generated/tree.html#jobspec\">here</a>  This command will attempt to submit a job and return its id.

        :param resource_id: (required)
        :type resource_id: str
        :param job_spec_input: (required)
        :type job_spec_input: JobSpecInput
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._launch_job_serialize(
            resource_id=resource_id,
            job_spec_input=job_spec_input,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def launch_job_without_preload_content(
        self,
        resource_id: StrictStr,
        job_spec_input: JobSpecInput,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Submit Job

        Submit a job on a compute resource  - **resource**: the name of the compute resource to use - **job_request**: a PSIJ job spec as defined <a href=\"https://exaworks.org/psij-python/docs/v/0.9.11/.generated/tree.html#jobspec\">here</a>  This command will attempt to submit a job and return its id.

        :param resource_id: (required)
        :type resource_id: str
        :param job_spec_input: (required)
        :type job_spec_input: JobSpecInput
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._launch_job_serialize(
            resource_id=resource_id,
            job_spec_input=job_spec_input,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _launch_job_serialize(
        self,
        resource_id,
        job_spec_input,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resource_id'] = resource_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if job_spec_input is not None:
            _body_params = job_spec_input


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/compute/job/{resource_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_job(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        job_spec_input: JobSpecInput,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Job:
        """Update Job

        Update a previously submitted job for a resource. Note that only some attributes of a scheduled job can be updated. Check the facility documentation for details.  - **resource**: the name of the compute resource to use - **job_request**: a PSIJ job spec as defined <a href=\"https://exaworks.org/psij-python/docs/v/0.9.11/.generated/tree.html#jobspec\">here</a>

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param job_spec_input: (required)
        :type job_spec_input: JobSpecInput
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            job_spec_input=job_spec_input,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_job_with_http_info(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        job_spec_input: JobSpecInput,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Job]:
        """Update Job

        Update a previously submitted job for a resource. Note that only some attributes of a scheduled job can be updated. Check the facility documentation for details.  - **resource**: the name of the compute resource to use - **job_request**: a PSIJ job spec as defined <a href=\"https://exaworks.org/psij-python/docs/v/0.9.11/.generated/tree.html#jobspec\">here</a>

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param job_spec_input: (required)
        :type job_spec_input: JobSpecInput
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            job_spec_input=job_spec_input,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_job_without_preload_content(
        self,
        resource_id: StrictStr,
        job_id: StrictStr,
        job_spec_input: JobSpecInput,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Job

        Update a previously submitted job for a resource. Note that only some attributes of a scheduled job can be updated. Check the facility documentation for details.  - **resource**: the name of the compute resource to use - **job_request**: a PSIJ job spec as defined <a href=\"https://exaworks.org/psij-python/docs/v/0.9.11/.generated/tree.html#jobspec\">here</a>

        :param resource_id: (required)
        :type resource_id: str
        :param job_id: (required)
        :type job_id: str
        :param job_spec_input: (required)
        :type job_spec_input: JobSpecInput
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_job_serialize(
            resource_id=resource_id,
            job_id=job_id,
            job_spec_input=job_spec_input,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Job",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_job_serialize(
        self,
        resource_id,
        job_id,
        job_spec_input,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resource_id'] = resource_id
        if job_id is not None:
            _path_params['job_id'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if job_spec_input is not None:
            _body_params = job_spec_input


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/v1/compute/job/{resource_id}/{job_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.api.compute_api import ComputeApi


class TestComputeApi(unittest.TestCase):
    """ComputeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ComputeApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_job(self) -> None:
        """Test case for cancel_job

        Cancel Job
        """
        pass

    def test_get_job(self) -> None:
        """Test case for get_job

        Get Job Status
        """
        pass

    def test_get_jobs(self) -> None:
        """Test case for get_jobs

        Get Job Statuses
        """
        pass

    def test_launch_job(self) -> None:
        """Test case for launch_job

        Submit Job
        """
        pass

    def test_update_job(self) -> None:
        """Test case for update_job

        Update Job
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.api.account_api import AccountApi


class TestAccountApi(unittest.TestCase):
    """AccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountApi()

    def tearDown(self) -> None:
        pass

    def test_get_capabilities(self) -> None:
        """Test case for get_capabilities

        Get the list of capabilities
        """
        pass

    def test_get_capability(self) -> None:
        """Test case for get_capability

        Get a single capability
        """
        pass

    def test_get_project(self) -> None:
        """Test case for get_project

        Get a single project
        """
        pass

    def test_get_project_allocation_by_project(self) -> None:
        """Test case for get_project_allocation_by_project

        Get a single project allocation
        """
        pass

    def test_get_project_allocations_by_project(self) -> None:
        """Test case for get_project_allocations_by_project

        Get the allocations of the current user's projects
        """
        pass

    def test_get_projects(self) -> None:
        """Test case for get_projects

        Get the projects of the current user
        """
        pass

    def test_get_user_allocation_by_project_allocation(self) -> None:
        """Test case for get_user_allocation_by_project_allocation

        Get a user allocation of the current user's projects
        """
        pass

    def test_get_user_allocations_by_project_allocation(self) -> None:
        """Test case for get_user_allocations_by_project_allocation

        Get the user allocations of the current user's projects
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AccountApi",
    "ComputeApi",
    "FacilityApi",
    "FilesystemApi",
    "StatusApi",
    "TaskApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AllocationEntry",
    "AllocationUnit",
    "Capability",
    "CompressionType",
    "Container",
    "Event",
    "Facility",
    "Incident",
    "IncidentType",
    "Job",
    "JobAttributes",
    "JobSpecInput",
    "JobSpecOutput",
    "JobState",
    "JobStatus",
    "PostCompressRequest",
    "PostCopyRequest",
    "PostExtractRequest",
    "PostFileSymlinkRequest",
    "PostMakeDirRequest",
    "PostMoveRequest",
    "Problem",
    "Project",
    "ProjectAllocation",
    "PutFileChmodRequest",
    "PutFileChownRequest",
    "Resolution",
    "Resource",
    "ResourceSpec",
    "ResourceType",
    "Site",
    "Status",
    "Task",
    "TaskCommand",
    "TaskStatus",
    "TaskSubmitResponse",
    "UserAllocation",
    "VolumeMount",
]

# import apis into sdk package
from esnet_iri.api.account_api import AccountApi as AccountApi
from esnet_iri.api.compute_api import ComputeApi as ComputeApi
from esnet_iri.api.facility_api import FacilityApi as FacilityApi
from esnet_iri.api.filesystem_api import FilesystemApi as FilesystemApi
from esnet_iri.api.status_api import StatusApi as StatusApi
from esnet_iri.api.task_api import TaskApi as TaskApi

# import ApiClient
from esnet_iri.api_response import ApiResponse as ApiResponse
from esnet_iri.api_client import ApiClient as ApiClient
from esnet_iri.configuration import Configuration as Configuration
from esnet_iri.exceptions import OpenApiException as OpenApiException
from esnet_iri.exceptions import ApiTypeError as ApiTypeError
from esnet_iri.exceptions import ApiValueError as ApiValueError
from esnet_iri.exceptions import ApiKeyError as ApiKeyError
from esnet_iri.exceptions import ApiAttributeError as ApiAttributeError
from esnet_iri.exceptions import ApiException as ApiException

# import models into sdk package
from esnet_iri.models.allocation_entry import AllocationEntry as AllocationEntry
from esnet_iri.models.allocation_unit import AllocationUnit as AllocationUnit
from esnet_iri.models.capability import Capability as Capability
from esnet_iri.models.compression_type import CompressionType as CompressionType
from esnet_iri.models.container import Container as Container
from esnet_iri.models.event import Event as Event
from esnet_iri.models.facility import Facility as Facility
from esnet_iri.models.incident import Incident as Incident
from esnet_iri.models.incident_type import IncidentType as IncidentType
from esnet_iri.models.job import Job as Job
from esnet_iri.models.job_attributes import JobAttributes as JobAttributes
from esnet_iri.models.job_spec_input import JobSpecInput as JobSpecInput
from esnet_iri.models.job_spec_output import JobSpecOutput as JobSpecOutput
from esnet_iri.models.job_state import JobState as JobState
from esnet_iri.models.job_status import JobStatus as JobStatus
from esnet_iri.models.post_compress_request import PostCompressRequest as PostCompressRequest
from esnet_iri.models.post_copy_request import PostCopyRequest as PostCopyRequest
from esnet_iri.models.post_extract_request import PostExtractRequest as PostExtractRequest
from esnet_iri.models.post_file_symlink_request import PostFileSymlinkRequest as PostFileSymlinkRequest
from esnet_iri.models.post_make_dir_request import PostMakeDirRequest as PostMakeDirRequest
from esnet_iri.models.post_move_request import PostMoveRequest as PostMoveRequest
from esnet_iri.models.problem import Problem as Problem
from esnet_iri.models.project import Project as Project
from esnet_iri.models.project_allocation import ProjectAllocation as ProjectAllocation
from esnet_iri.models.put_file_chmod_request import PutFileChmodRequest as PutFileChmodRequest
from esnet_iri.models.put_file_chown_request import PutFileChownRequest as PutFileChownRequest
from esnet_iri.models.resolution import Resolution as Resolution
from esnet_iri.models.resource import Resource as Resource
from esnet_iri.models.resource_spec import ResourceSpec as ResourceSpec
from esnet_iri.models.resource_type import ResourceType as ResourceType
from esnet_iri.models.site import Site as Site
from esnet_iri.models.status import Status as Status
from esnet_iri.models.task import Task as Task
from esnet_iri.models.task_command import TaskCommand as TaskCommand
from esnet_iri.models.task_status import TaskStatus as TaskStatus
from esnet_iri.models.task_submit_response import TaskSubmitResponse as TaskSubmitResponse
from esnet_iri.models.user_allocation import UserAllocation as UserAllocation
from esnet_iri.models.volume_mount import VolumeMount as VolumeMount




# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.api.filesystem_api import FilesystemApi


class TestFilesystemApi(unittest.TestCase):
    """FilesystemApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FilesystemApi()

    def tearDown(self) -> None:
        pass

    def test_checksum(self) -> None:
        """Test case for checksum

        Get Checksum
        """
        pass

    def test_chmod(self) -> None:
        """Test case for chmod

        Put Chmod
        """
        pass

    def test_chown(self) -> None:
        """Test case for chown

        Put Chown
        """
        pass

    def test_compress(self) -> None:
        """Test case for compress

        Post Compress
        """
        pass

    def test_cp(self) -> None:
        """Test case for cp

        Post Cp
        """
        pass

    def test_download(self) -> None:
        """Test case for download

        Get Download
        """
        pass

    def test_extract(self) -> None:
        """Test case for extract

        Post Extract
        """
        pass

    def test_file(self) -> None:
        """Test case for file

        Get File
        """
        pass

    def test_head(self) -> None:
        """Test case for head

        Get Head
        """
        pass

    def test_ls(self) -> None:
        """Test case for ls

        Get Ls Async
        """
        pass

    def test_mkdir(self) -> None:
        """Test case for mkdir

        Post Mkdir
        """
        pass

    def test_mv(self) -> None:
        """Test case for mv

        Move Mv
        """
        pass

    def test_rm(self) -> None:
        """Test case for rm

        Delete Rm
        """
        pass

    def test_stat(self) -> None:
        """Test case for stat

        Get Stat
        """
        pass

    def test_symlink(self) -> None:
        """Test case for symlink

        Post Symlink
        """
        pass

    def test_tail(self) -> None:
        """Test case for tail

        Get Tail
        """
        pass

    def test_upload(self) -> None:
        """Test case for upload

        Post Upload
        """
        pass

    def test_view(self) -> None:
        """Test case for view

        Get View
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.project import Project

class TestProject(unittest.TestCase):
    """Project unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Project:
        """Test Project
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Project`
        """
        model = Project()
        if include_optional:
            return Project(
                id = 'proj-abc123',
                name = 'Climate Simulation',
                description = 'Research project studying atmospheric dynamics.',
                user_ids = [user-123, user-456],
                last_modified = '2026-02-21T14:30:00Z',
                self_uri = ''
            )
        else:
            return Project(
                id = 'proj-abc123',
                name = 'Climate Simulation',
                description = 'Research project studying atmospheric dynamics.',
                user_ids = [user-123, user-456],
                last_modified = '2026-02-21T14:30:00Z',
                self_uri = '',
        )
        """

    def testProject(self):
        """Test Project"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.job import Job

class TestJob(unittest.TestCase):
    """Job unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Job:
        """Test Job
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Job`
        """
        model = Job()
        if include_optional:
            return Job(
                id = 'job-12345',
                status = {
                    'key' : null
                    },
                job_spec = esnet_iri.models.job_spec.JobSpec(
                    executable = '/usr/bin/python', 
                    container = null, 
                    arguments = [-n, 100], 
                    directory = '/home/user/work', 
                    name = 'my-job', 
                    inherit_environment = True, 
                    environment = {OMP_NUM_THREADS=4}, 
                    stdin_path = '/home/user/input.txt', 
                    stdout_path = '/home/user/output.txt', 
                    stderr_path = '/home/user/error.txt', 
                    resources = null, 
                    attributes = null, 
                    pre_launch = 'module load cuda', 
                    post_launch = 'echo done', 
                    launcher = 'srun', )
            )
        else:
            return Job(
                id = 'job-12345',
        )
        """

    def testJob(self):
        """Test Job"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from esnet_iri.models.facility import Facility
from esnet_iri.models.site import Site

from esnet_iri.api_client import ApiClient, RequestSerialized
from esnet_iri.api_response import ApiResponse
from esnet_iri.rest import RESTResponseType


class FacilityApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_facility(
        self,
        modified_since: Optional[datetime] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Facility:
        """Get Facility

        Get facility information

        :param modified_since:
        :type modified_since: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_facility_serialize(
            modified_since=modified_since,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Facility",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_facility_with_http_info(
        self,
        modified_since: Optional[datetime] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Facility]:
        """Get Facility

        Get facility information

        :param modified_since:
        :type modified_since: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_facility_serialize(
            modified_since=modified_since,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Facility",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_facility_without_preload_content(
        self,
        modified_since: Optional[datetime] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Facility

        Get facility information

        :param modified_since:
        :type modified_since: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_facility_serialize(
            modified_since=modified_since,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Facility",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_facility_serialize(
        self,
        modified_since,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if modified_since is not None:
            if isinstance(modified_since, datetime):
                _query_params.append(
                    (
                        'modified_since',
                        modified_since.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('modified_since', modified_since))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/facility',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_site(
        self,
        site_id: StrictStr,
        modified_since: Optional[datetime] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Site:
        """Get Site

        Get site by ID

        :param site_id: (required)
        :type site_id: str
        :param modified_since:
        :type modified_since: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_serialize(
            site_id=site_id,
            modified_since=modified_since,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Site",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_site_with_http_info(
        self,
        site_id: StrictStr,
        modified_since: Optional[datetime] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Site]:
        """Get Site

        Get site by ID

        :param site_id: (required)
        :type site_id: str
        :param modified_since:
        :type modified_since: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_serialize(
            site_id=site_id,
            modified_since=modified_since,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Site",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_site_without_preload_content(
        self,
        site_id: StrictStr,
        modified_since: Optional[datetime] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Site

        Get site by ID

        :param site_id: (required)
        :type site_id: str
        :param modified_since:
        :type modified_since: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_serialize(
            site_id=site_id,
            modified_since=modified_since,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Site",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_site_serialize(
        self,
        site_id,
        modified_since,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['site_id'] = site_id
        # process the query parameters
        if modified_since is not None:
            if isinstance(modified_since, datetime):
                _query_params.append(
                    (
                        'modified_since',
                        modified_since.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('modified_since', modified_since))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/facility/sites/{site_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_sites(
        self,
        modified_since: Optional[datetime] = None,
        name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        offset: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        limit: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        short_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Site]:
        """List Sites

        List sites

        :param modified_since:
        :type modified_since: datetime
        :param name:
        :type name: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param short_name:
        :type short_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sites_serialize(
            modified_since=modified_since,
            name=name,
            offset=offset,
            limit=limit,
            short_name=short_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Site]",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_sites_with_http_info(
        self,
        modified_since: Optional[datetime] = None,
        name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        offset: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        limit: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        short_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Site]]:
        """List Sites

        List sites

        :param modified_since:
        :type modified_since: datetime
        :param name:
        :type name: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param short_name:
        :type short_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sites_serialize(
            modified_since=modified_since,
            name=name,
            offset=offset,
            limit=limit,
            short_name=short_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Site]",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_sites_without_preload_content(
        self,
        modified_since: Optional[datetime] = None,
        name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        offset: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        limit: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = None,
        short_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Sites

        List sites

        :param modified_since:
        :type modified_since: datetime
        :param name:
        :type name: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param short_name:
        :type short_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_sites_serialize(
            modified_since=modified_since,
            name=name,
            offset=offset,
            limit=limit,
            short_name=short_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Site]",
            '400': "Problem",
            '401': "Problem",
            '403': "Problem",
            '404': "Problem",
            '405': "Problem",
            '409': "Problem",
            '422': "Problem",
            '500': "Problem",
            '501': "Problem",
            '503': "Problem",
            '504': "Problem",
            '304': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_sites_serialize(
        self,
        modified_since,
        name,
        offset,
        limit,
        short_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if modified_since is not None:
            if isinstance(modified_since, datetime):
                _query_params.append(
                    (
                        'modified_since',
                        modified_since.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('modified_since', modified_since))
            
        if name is not None:
            
            _query_params.append(('name', name))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if short_name is not None:
            
            _query_params.append(('short_name', short_name))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/facility/sites',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.put_file_chown_request import PutFileChownRequest

class TestPutFileChownRequest(unittest.TestCase):
    """PutFileChownRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PutFileChownRequest:
        """Test PutFileChownRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PutFileChownRequest`
        """
        model = PutFileChownRequest()
        if include_optional:
            return PutFileChownRequest(
                path = '',
                owner = '',
                group = ''
            )
        else:
            return PutFileChownRequest(
        )
        """

    def testPutFileChownRequest(self):
        """Test PutFileChownRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from esnet_iri.api.account_api import AccountApi
from esnet_iri.api.compute_api import ComputeApi
from esnet_iri.api.facility_api import FacilityApi
from esnet_iri.api.filesystem_api import FilesystemApi
from esnet_iri.api.status_api import StatusApi
from esnet_iri.api.task_api import TaskApi

